@@ -106,9 +106,9 @@
 /* Copy the first part of user declarations.  */
 #line 17 "msgparse.y"
 
+#include "config.h"
 #include <stdio.h>
-#include <malloc.h>
-#include <string.h>
+#include "incl_unix.h"
 #include "hdefs.h"
 
 extern	void	nomem();
